pub enum BindError {
TooManyArgumentsBound,
TooFewArgumentsBound,
TryFromInt(TryFromIntError),
}Expand description
Error type returned by Bind::bind
Variants
TooManyArgumentsBound
To many argument has been bound to the query
TooFewArgumentsBound
Not enough arguments has been bound to the query
TryFromInt(TryFromIntError)
Error converting between