Connection

Struct Connection 

pub struct Connection { /* private fields */ }
A connection to Mariadb/Mysql

Implementations

Source

impl Connection

pub async fn connect(options: &ConnectionOptions<'_>) -> ConnectionResult<Self>

Connect to Mariadb/Mysql

pub fn is_clean(&self) -> bool

Return false if there are partially execute queries in the connection

pub async fn cleanup(&mut self) -> ConnectionResult<()>

Finish up any partially execute queries as quickly as possible