pub struct QueryOptions { /* private fields */ }Expand description
Options for preparing queries
Implementations
Sourceimpl QueryOptions
impl QueryOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct default options with caching enabled and column information disabled
Sourcepub fn cache(self, enable: bool) -> Self
pub fn cache(self, enable: bool) -> Self
Add the prepared statement to the prepared statement cache
Sourcepub fn information(self, enable: bool) -> Self
pub fn information(self, enable: bool) -> Self
Store type information about columns and parameters