DecodeError

Enum DecodeError 

pub enum DecodeError {
    EndOfPackage,
    EndOfColumns,
    Utf8Error {
        valid_up_to: u32,
        error_len: Option<u8>,
    },
    Null,
    ExpectedUnsigned,
    ExpectedSigned,
    TypeError {
        got: u8,
        expected: u8,
    },
    InvalidSize(u8),
    InvalidValue,
    TryFromInt,
}
Error returned by the PackageParser

Variants



EndOfPackage

The package was shorter than expected



EndOfColumns

You are decoding more columns than there is in the response



Utf8Error

A string in a package was not utf-8 as expected

Fields

valid_up_to: u32

The string is valid utf-8 until this many bytes

error_len: Option<u8>

The length of the error



Null

We expected a non-null value, but found null



ExpectedUnsigned

We expected an unsigned integer but we got aa signed integer



ExpectedSigned

We expected an signed integer but we got aa unsigned integer



TypeError

The field we are decoding has a different type than expected

Fields

got: u8

The field has this type as defined in crate::constants::type_

expected: u8

We expected this type



InvalidSize(u8)

A variable length encoded field has an unexpected size



InvalidValue

The value could not be converted to the target type



TryFromInt

Error converting between integer types