Pool

Struct Pool 

pub struct Pool(/* private fields */);
A pool of shared connections that can be acquired

Implementations

Source

impl Pool

pub async fn connect( connection_options: ConnectionOptions<'static>, pool_options: PoolOptions, ) -> ConnectionResult<Self>

Establish a new pool with at least one connection

pub async fn acquire(&self) -> ConnectionResult<PoolConnection>

Acquire a free connection from the pool.

If there is no free connection wait for one to become available

The returned future is drop safe