pub struct Connection { /* private fields */ }Expand description
A connection to Mariadb/Mysql
Implementations
Sourceimpl Connection
impl Connection
Sourcepub async fn connect(options: &ConnectionOptions<'_>) -> ConnectionResult<Self>
pub async fn connect(options: &ConnectionOptions<'_>) -> ConnectionResult<Self>
Connect to Mariadb/Mysql
Sourcepub fn is_clean(&self) -> bool
pub fn is_clean(&self) -> bool
Return false if there are partially execute queries in the connection
Sourcepub async fn cleanup(&mut self) -> ConnectionResult<()>
pub async fn cleanup(&mut self) -> ConnectionResult<()>
Finish up any partially execute queries as quickly as possible